@@ -178,3 +178,10 @@ rs_avail <- function(){
   }
 }
 
+MNI305_to_MNI152 <- matrix(
+  c(c(0.9975, 0.0146, -0.013, 0,
+      -0.0073, 1.0009, -0.0093, 0,
+      0.0176, -0.0024, 0.9971, 0,
+      -0.0429, 1.5496, 1.184, 1)),
+  nrow = 4L, byrow = FALSE
+)
